@@ -120,11 +120,18 @@ module Parser
     end
     private :numeric
 
-    def negate(uminus_t, numeric)
+    def unary_num(unary_t, numeric)
       value, = *numeric
-      operator_loc = loc(uminus_t)
+      operator_loc = loc(unary_t)
 
-      numeric.updated(nil, [ -value ],
+      case value(unary_t)
+      when '+'
+        value = +value
+      when '-'
+        value = -value
+      end
+
+      numeric.updated(nil, [ value ],
         :location =>
           Source::Map::Operator.new(
             operator_loc,
@@ -878,7 +885,7 @@ module Parser
 
     def not_op(not_t, begin_t=nil, receiver=nil, end_t=nil)
       if @parser.version == 18
-        n(:not, [ receiver ],
+        n(:not, [ check_condition(receiver) ],
           unary_op_map(not_t, receiver))
       else
         if receiver.nil?
@@ -888,7 +895,7 @@ module Parser
             nil_node, :'!'
           ], send_unary_op_map(not_t, nil_node))
         else
-          n(:send, [ receiver, :'!' ],
+          n(:send, [ check_condition(receiver), :'!' ],
             send_map(nil, nil, not_t, begin_t, [receiver], end_t))
         end
       end
@@ -1097,6 +1104,8 @@ module Parser
       when :masgn
         if @parser.version <= 23
           diagnostic :error, :masgn_as_condition, nil, cond.loc.expression
+        else
+          cond
         end
 
       when :begin
@@ -1271,6 +1280,10 @@ module Parser
       if begin_t.nil? || end_t.nil?
         if parts.any?
           expr_l = join_exprs(parts.first, parts.last)
+        elsif !begin_t.nil?
+          expr_l = loc(begin_t)
+        elsif !end_t.nil?
+          expr_l = loc(end_t)
         end
       else
         expr_l = loc(begin_t).join(loc(end_t))
