@@ -18,6 +18,8 @@ class TestCurrent < Minitest::Test
       assert_equal Parser::Ruby23, Parser::CurrentRuby
     when /^2\.4\.\d+/
       assert_equal Parser::Ruby24, Parser::CurrentRuby
+    when /^2\.5\.\d+/
+      assert_equal Parser::Ruby25, Parser::CurrentRuby
     else
       flunk "Update test_current for #{RUBY_VERSION}"
     end
